Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit 1cd6416


[ROCm/clr commit: 4966518846]
This commit is contained in:
Alex Voicu
2017-11-29 21:49:10 +00:00
orang tua e0a41791c8
melakukan a27fa25d76
63 mengubah file dengan 171 tambahan dan 173 penghapusan
+2 -2
Melihat File
@@ -45,8 +45,8 @@ __device__ void *__hip_hc_malloc(size_t size)
{
return (void*)nullptr;
}
uint32_t totalThreads = hipBlockDim_x * hipGridDim_x * hipBlockDim_y * hipGridDim_y * hipBlockDim_z * hipGridDim_z;
uint32_t currentWorkItem = hipThreadIdx_x + hipBlockDim_x * hipBlockIdx_x;
uint32_t totalThreads = blockDim.x * gridDim.x * blockDim.y * gridDim.y * blockDim.z * gridDim.z;
uint32_t currentWorkItem = threadIdx.x + blockDim.x * blockIdx.x;
uint32_t numHeapsPerWorkItem = NUM_PAGES / totalThreads;
uint32_t heapSizePerWorkItem = SIZE_OF_HEAP / totalThreads;
+2 -2
Melihat File
@@ -1307,9 +1307,9 @@ namespace
__global__
void hip_fill_n(RandomAccessIterator f, N n, T value)
{
const uint32_t grid_dim = hipGridDim_x * hipBlockDim_x;
const uint32_t grid_dim = gridDim.x * blockDim.x;
size_t idx = hipBlockIdx_x * block_dim + hipThreadIdx_x;
size_t idx = blockIdx.x * block_dim + threadIdx.x;
while (idx < n) {
__builtin_memcpy(
reinterpret_cast<void*>(&f[idx]),